@@ -2,6 +2,22 @@ package App::Wax;
 
 use 5.008008;
 
+use Digest::SHA qw(sha1_hex);
+use File::Slurp qw(read_file write_file);
+use File::Spec;
+use File::Temp;
+use IPC::System::Simple qw(EXIT_ANY $EXITVAL systemx);
+use LWP::UserAgent;
+use Method::Signatures::Simple;
+use MIME::Types;
+use Mouse;
+use Parallel::parallel_map qw(parallel_map);
+use Pod::Usage qw(pod2usage);
+use Try::Tiny qw(try catch);
+use URI::Split qw(uri_split);
+
+our $VERSION = '1.0.1';
+
 # defaults
 use constant {
     CACHE      => 0,
@@ -25,22 +41,6 @@ use constant {
     E_INVALID_OPTION    => -6,
 };
 
-use Digest::SHA qw(sha1_hex);
-use File::Slurp qw(read_file write_file);
-use File::Spec;
-use File::Temp;
-use IPC::System::Simple qw(EXIT_ANY $EXITVAL systemx);
-use LWP::UserAgent;
-use Method::Signatures::Simple;
-use MIME::Types;
-use Mouse;
-use Parallel::parallel_map qw(parallel_map);
-use Pod::Usage qw(pod2usage);
-use Try::Tiny qw(try catch);
-use URI::Split qw(uri_split);
-
-our $VERSION = '1.0.0';
-
 has app_name => (
     is      => 'rw',
     isa     => 'Str',
@@ -264,7 +264,7 @@ method render ($args) {
 }
 
 method resolve ($url) {
-    my ($error, $filename);
+    my ($error, $filename, @resolved);
 
     if ($self->keep) {
         ($filename, $error) = $self->resolve_keep($url);
@@ -273,8 +273,9 @@ method resolve ($url) {
     }
 
     $error ||= $self->download($url, $filename);
+    @resolved = ($filename, $error);
 
-    return [ $filename, $error ];
+    return wantarray ? @resolved : \@resolved;
 }
 
 method resolve_keep ($url) {
@@ -326,7 +327,7 @@ method run ($argv) {
     unless (@argv) {
         pod2usage(
             -exitval => E_NO_ARGUMENTS,
-            -input   => "$0.pod",
+            -input   => $0,
             -msg     => 'no arguments supplied',
             -verbose => 0,
         );
@@ -398,13 +399,13 @@ method run ($argv) {
     if (@resolve) {
         if (@resolve == 1) {
             my ($index, $url) = @{ $resolve[0] };
-            my $resolved = $self->resolve($url);
+            my @resolved = $self->resolve($url);
 
-            $error = $self->_handle([ $index, @$resolved ], \@command, \@cleanup);
+            $error = $self->_handle([ $index, @resolved ], \@command, \@cleanup);
         } else {
             $self->debug('jobs: %d', scalar(@resolve));
 
-            my @resolved = parallel_map { [ $_->[0], @{ scalar $self->resolve($_->[1]) } ] } @resolve;
+            my @resolved = parallel_map { [ $_->[0], $self->resolve($_->[1]) ] } @resolve;
 
             for my $resolved (@resolved) {
                 $error ||= $self->_handle($resolved, \@command, \@cleanup);
